.. include:: ../README.rst


.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: User Guide

   What is SINDy? <summary>
   Examples <examples/index>
   Practical tips <tips>
   Contributing <contributing>
   Using pysindy in academia <academic>
   Object Model <objects>
   API Documentation <generated/pysindy>

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Useful links

   PySINDy @ PyPI <https://pypi.org/project/PySINDy/>
   Issue Tracker <https://github.com/dynamicslab/pysindy/issues>
